%% ****************************************************************
%%    Copyright 2024 by latexstudio-xmyphys <latexstudio.net>     *
%%                                                                *
%%    The Current Maintainers of this work is latexstudio-xmyphys *
%%                                                                *
%%    This work consists of the files Globasci.cls                *
%% ****************************************************************
% \def\Globasci@date{2024/07/21}
% \def\Globasci@version{V1}
% 
% \ProvidesExplClass {Globasci} {\Globasci@date} {\Globasci@version}
%   {Template for GLOBA by latexstudio-xmyphys}
% \ProvidesClass{Globasci}[Template for GLOBA 20240721 V1 by latexstudio-xmyphys]
\ProvidesClass{Globasci}[Template for GLOBA 20240721 V1 by latexstudio_xmyphys]

\LoadClass[twoside]{article}

\RequirePackage{etoolbox}

\RequirePackage{fontspec}

\RequirePackage{mathptmx}
\RequirePackage[OT1]{fontenc}

\RequirePackage[labelsep=period,labelfont=bf]{caption}

\RequirePackage{amsmath,hyperref,cleveref}
\hypersetup{hidelinks}
\crefname{figure}{\textbf{Figure}}{\textbf{Figure}}
\crefname{table}{\textbf{Table}}{\textbf{Table}}
\crefname{equation}{equation}{equation}
\numberwithin{equation}{section}

\RequirePackage{xcolor,array,booktabs,enumitem}
\setlist[itemize,1]{leftmargin=2.5em,labelsep=2em,itemsep=0em}
\setlist[enumerate,1]{leftmargin=1.75em,labelsep=1em,itemsep=0em,label=\arabic*)}
\setlist[enumerate,2]{leftmargin=-.25em,labelsep=.5em,itemsep=0em,label=(\alph*)}

\RequirePackage{tikz,fancyhdr,geometry}
\RequirePackage{calc}

\def\Gmt@restore{}
\apptocmd\Gm@savelength{%
  \g@addto@macro\Gmt@restore{\global\expandafter\noexpand\expandafter\csname
  #1\endcsname\expandafter=\expandafter\the\csname #1\endcsname\relax}}{}{}
\patchcmd{\@outputpage}{\global \@colht \textheight}{\Gmt@restore@pkg \global \@colht \textheight}{}{} 
\newgeometry{top=.93in,bottom=1.07in,left=.9in,right=.9in,headsep=12pt}
\savegeometry{standard}

\edef\Gmt@restore@pkg{\Gmt@restore
\global\expandafter\let\expandafter\noexpand\expandafter\Gmt@restore@pkg\noexpand\empty}%
\newgeometry{top=1.78in,bottom=.42in,left=.9in,right=.9in,headsep=.87in,headheight=1in,headsep = .54in, footskip = 0in}
\savegeometry{title}

\loadgeometry{standard}

\newlength{\headruleleft}
\setlength{\headruleleft}{(\paperwidth-\textwidth)/2}
\newlength{\headruletop}
\setlength{\headruletop}{(\paperheight-\textheight)/2-\headheight}
\setlength{\parindent}{0em}
\setlength{\headheight}{30pt}

\RequirePackage{titlesec}
\titleformat{\section}{\large\bfseries}{\arabic{section}.}{.75ex}{}
\titleformat{\subsection}{\bfseries}{\thesubsection}{.75ex}{}

\RequirePackage{lettrine}
\let\LettrineTextFont\relax

\RequirePackage[framemethod=TikZ]{mdframed}

\RequirePackage{keyval}
\define@key{articleset}{firstrhead}{\gdef\@firstrhead{#1}}
\define@key{articleset}{articletype}{\gdef\@articletype{#1}}
\define@key{articleset}{title}{\title{#1}}
\define@key{articleset}{author}{\author{#1*}}
\define@key{articleset}{affliction}{\gdef\@affliction{#1}}
\define@key{articleset}{correspond}{\gdef\@correspond{#1}}
\define@key{articleset}{citation}{\gdef\@citation{#1}}
\define@key{articleset}{received}{\gdef\@received{#1}}
\define@key{articleset}{revised}{\gdef\@revised{#1}}
\define@key{articleset}{accepted}{\gdef\@accepted{#1}}
\define@key{articleset}{published}{\gdef\@published{#1}}
\define@key{articleset}{lhead}{\gdef\@lhead{#1}}
\define@key{articleset}{rhead}{\gdef\@rhead{#1}}
\define@key{articleset}{copyright}{\gdef\@copyright{#1}}
\define@key{articleset}{website}{\gdef\@website{#1}}

\def\articleset#1{\setkeys{articleset}{#1}}

\RequirePackage{setspace}

\renewcommand*\maketitle
  {
    \loadgeometry{title}
    \fancypagestyle{firststyle}{
    \fancyhf{}
    \ifcsname @firstrhead\endcsname
      \rhead
        { \fontspec{Alibaba-PuHuiTi-Regular.ttf}\selectfont\@rhead\@firstrhead }
    \else
      \rhead{}
    \fi
    \lhead{\includegraphics[height = 2.5em]{page1-4-trimmed}}
    \ifcsname @copyright\endcsname
      \lfoot{ \raisebox{.5em}{\small\bfseries\color{headrulecolor}\@copyright} }
    \fi
    \ifcsname @website\endcsname
      \rfoot{ \includegraphics[height = 1.5em]{\@website}\quad}
    \fi
    }
    \begin{figure}[b]
      \linespread{1.2}
      \noindent\parbox{\dimexpr\linewidth-2\fboxsep-2\fboxrule\relax}
        {\footnotesize
          \lettrine[ lines = 2, nindent = 0em ]
          {\includegraphics[ height = 1.75ex, width = 4.5ex ]{page1-1}~}
          {\copyright} \textbf{The Author(s) 2025.}
          This is an Open Access article licensed under a Creative Commons Attribution 4.0 International License
          (\url{https://creativecommons.org/licenses/by/4.0/}), which permits
          unrestricted use, sharing, adaptation, distribution and reproduction
          in any medium or format, for any purpose, even commercially, as long
          as you give appropriate credit to the original author(s) and the
          source, provide a link to the Creative Commons license, and indicate
          if changes were made.}%
    \end{figure}
    \tikz[remember picture,overlay]
      {
        \ifcsname @articletype\endcsname
          \node [ below right, black ] at
            ([shift = {(\headruleleft,-1.32in)}]current page.north west)
            {
              \large \bfseries
              \textcolor{red!80!black}{Open Access} \@articletype
            };
        \fi
        \node [ below left, inner sep = 0pt ] at
          ([shift = {(-\headruleleft,-1.32in)}]current page.north east)
          {
            \href{https://crossmark.crossref.org/dialog?doi=10.70401/ec.2025.0002\&domain=pdf\&date\_stamp=2024-12-06}
            {\includegraphics[height = 2.5em]{page1-3}}
          };
    }
    \parbox[l]{\linewidth}
    {
      \linespread{1.35} \bfseries \sffamily
      % \fontspec{Alibaba-PuHuiTi-Regular.ttf}\selectfont
      \LARGE\@title
    }
    \vskip4.5ex
    \setstretch{1.2}
      \ifcsname @author\endcsname
      {\bfseries\@author}
    \fi
    \fancyhead[OL]{}
    \fancyhead[ER]{}
    \ifcsname @rhead\endcsname
      \fancyhead[OR]
        {\rule[-2ex]{0pt}{2ex}\small\fontspec{Alibaba-PuHuiTi-Regular.ttf}\selectfont\@rhead{}~}
    \else
        \fancyhead[OR]{}
    \fi
    \ifcsname @lhead\endcsname
      \fancyhead[EL]
        {
          \rule[-2ex]{0pt}{2ex}
          \small\fontspec{Alibaba-PuHuiTi-Regular.ttf}\selectfont\@lhead
        }
    \else
        \fancy[EL]{}
    \fi
    \cfoot{}
    \pagestyle{fancy}
    \ifcsname @affliction\endcsname
        \vskip1.5ex\@affliction
    \fi
    \setstretch{1}
    \ifcsname @correspond\endcsname
        \vskip3ex\textbf{*Correspondence to:} \@correspond
    \fi
    \vskip1.5ex
    \ifcsname @received\endcsname
        \textbf{Received:} \@received~
    \fi
    \ifcsname @revised\endcsname
        \textbf{Revised:} \@revised~
    \fi
    \ifcsname @accepted\endcsname
        \textbf{Accepted:} \@accepted~
    \fi
    \ifcsname @published\endcsname
        \textbf{Published:} \@published
    \fi
    \vskip1ex
    \ifcsname @citation\endcsname
        \vskip1.5ex\textbf{Cite this article:} \@citation
    \fi
    \thispagestyle{firststyle}
    \def\headrulewidth{1pt}
    \definecolor{headrulecolor}{HTML}{285EA7}
    \let\tmp@headrule\headrule
    \def\headrule{\color{headrulecolor}\tmp@headrule}
}

\RequirePackage{xcolor}
\definecolor{abstractback}{HTML}{CAE7F0}

\renewenvironment{abstract}{\begin{mdframed}
    [innerleftmargin=1ex,innerrightmargin=1ex,linewidth=0pt,backgroundcolor=abstractback,roundcorner=1em]
    \textbf{Abstract}\setstretch{1.25}\par}{\end{mdframed}}

\let\OLDthebibliography\thebibliography
\renewcommand\thebibliography[1]{
  \OLDthebibliography{#1}
  \setlength{\parskip}{0pt}
  \setlength{\itemsep}{0ex}
}
\let\tmp@bibliography\bibliography
\def\bibliography#1{\begingroup
\renewcommand\section[2]{\vspace{-1em}}
\tmp@bibliography{#1}
\endgroup}

\RequirePackage{cite}
% \def\@cite#1#2{\textsuperscript{[{#1\if@tempswa , #2\fi}]}}

\RequirePackage{soul}
\setulcolor{blue}
\def\url#1{\begingroup\color{blue}\ul{#1}\endgroup}

\RequirePackage{graphicx}
\graphicspath{{./figure/}{./figures/}{./image/}{./images/}{./graphics/}{./graphic/}{./pictures/}{./picture/}}

%\titleformat{\section}{\large\bfseries}{Appendix~\Alph{section}.}{.75ex}{}
\def\@seccntformat#1{\@ifundefined{#1@cntformat}%
   {\csname the#1\endcsname\quad}%   default
   {\csname #1@cntformat\endcsname}% enable individual control
}
\renewcommand\appendix{\par%
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \gdef\thesection{\@Alph\c@section}%
  \titleformat{\section}{\large\bfseries}{Appendix~\Alph{section}.}{.75ex}{}
}

\renewcommand{\@biblabel}[1]{\textsf{ #1.}}

\renewcommand\section{\@startsection {section}{1}{\z@}%
{-3.5ex \@plus -1ex \@minus -.2ex}%
{1.8ex \@plus.2ex}%
{\vspace{-1ex}\normalfont\normalsize\bfseries}}
 
%%
%% End of file `globisci.cls'.
